@@ -1,9 +1,10 @@
-from .named import named_arg
 from .bindings import AbstractModule, ClassBinding, InstanceBinding, ItemBinding, Module, MultiBinding, PrivateModule, \
     ProviderBinding, SelfBinding
-from .exceptions import NamedError, BindingError, InjectException, NoBindingFound, NonInjectableTypeError
+from .conditions import conditional_on_env_var
+from .exceptions import BindingError, InjectException, NamedError, NoBindingFound, NonInjectableTypeError
 from .injector import Injector
 from .injector_options import InjectorOptions
+from .named import named_arg
 from .provider import Provider
 from .scopes import ImmediateScope, PerLookupScope, SingletonScope, ThreadScope
 from .target import Target
