@@ -18,6 +18,11 @@ class BindingError(InjectException):
     pass
 
 
-class AnnotationError(InjectException):
-    """Raised when annotated_arg is used with an unexpected argument."""
+class NamedError(InjectException):
+    """Raised when named_arg is used with an unexpected argument."""
+    pass
+
+
+class CyclicDependencyError(InjectException):
+    """Raised when a cyclic dependency is detected."""
     pass
